<?php

/**
 * Implements hook_css_alter().
 */
function stanley_css_alter(&$css) {
  if (isset($css['modules/overlay/overlay-child.css'])) {
    $css['modules/overlay/overlay-child.css']['data'] = drupal_get_path('theme', 'stanley') . '/styles/overlay-child.css';
  }

  if (isset($css['misc/ui/jquery.ui.theme.css'])) {
    $css['misc/ui/jquery.ui.theme.css']['data'] = drupal_get_path('theme', 'stanley') . '/styles/jquery.ui.theme.css';
    $css['misc/ui/jquery.ui.theme.css']['weight']++;
  }

  //unset date_popup date picker css, core already has a theme
  unset($css['sites/all/modules/contrib/date/date_popup/themes/datepicker.1.7.css']);

  // unset core css
  unset($css['modules/dblog/dblog.css']);
  unset($css['modules/menu/menu.css']);
  unset($css['modules/system/system.menus.css']);
  unset($css['modules/system/system.messages.css']);
  unset($css['modules/system/system.theme.css']);
}

/**
 * Implements hook_page_alter().
 */
function stanley_page_alter(&$page) {
  $css_options = array(
    'group' => CSS_THEME,
    'media' => 'screen',
    'every_page' => TRUE,
  );

  // add toolbar css
  if (module_exists('toolbar') && user_access('access toolbar')) {
    drupal_add_css(drupal_get_path('theme', 'stanley') . '/styles/modules/core.toolbar.css', $css_options);
  }

  // add admin toolbar css
  if (module_exists('admin') && user_access('use admin toolbar')) {
    drupal_add_css(drupal_get_path('theme', 'stanley') . '/styles/modules/contrib.admin.toolbar.css', $css_options);
  }
}

/**
 * Implementation of hook_preprocess_html().
 */
function stanley_preprocess_html(&$vars) {
  // Add body class for theme.
  $vars['classes_array'][] = 'stanley';

  // HTML5 shiv -> http://code.google.com/p/html5shiv/
  $vars['shiv'] = '<!--[if lt IE 9]>' . "\n" . '<script src="//html5shim.googlecode.com/svn/trunk/html5.js"></script>' . "\n" . '<![endif]-->';

  // Don't assume RDFa is enabled and don't use XHTML if it is
  if (module_exists('rdf')) {
    $vars['doctype'] = '<!DOCTYPE html PUBLIC "-//W3C//DTD HTML+RDFa 1.1//EN">' . "\n";
    $vars['rdf_version'] = ' version="HTML+RDFa 1.1"';
    $vars['rdf_profile'] = ' profile="' . $vars['grddl_profile'] . '"';
  }
  else {
    $vars['doctype'] = '<!DOCTYPE html>' . "\n";
    $vars['rdf_version'] = '';
    $vars['rdf_profile'] = '';
  }
}

/**
 * Preprocessor for theme('page').
 */
function stanley_preprocess_page(&$vars) {
  // Overlay is enabled.
  $vars['overlay'] = (module_exists('overlay') && overlay_get_mode() === 'child');

  // Toolbar is enabled
  $vars['toolbar'] = module_exists('toolbar');

  // local tasks
  $vars['primary_local_tasks'] = $vars['secondary_local_tasks'] = FALSE;
  if (!empty($vars['tabs']['#primary'])) {
    $vars['primary_local_tasks'] = $vars['tabs'];
    unset($vars['primary_local_tasks']['#secondary']);
  }
  if (!empty($vars['tabs']['#secondary'])) {
    $vars['secondary_local_tasks'] = array(
      '#theme' => 'menu_local_tasks',
      '#secondary' => $vars['tabs']['#secondary'],
    );
  }

  // Set a page icon class.
  $vars['page_icon_class'] = ($item = menu_get_item()) ? implode(' ' , _stanley_icon_classes($item['href'])) : '';
}

/**
 * Implementation of theme_breadcrumb().
 */
function stanley_breadcrumb($vars) {
  //add divider
  foreach ($vars['breadcrumb'] as $key => $link) {
    $vars['breadcrumb'][$key] = $link . ' <span class="divider">/</span>';
  }

  // Add current page onto the end.
  if (!drupal_is_front_page()) {
    $item = menu_get_item();
    $end = end($vars['breadcrumb']);
    if ($end && strip_tags($end) !== $item['title']) {
      $vars['breadcrumb'][] = check_plain($item['title']);
    }
  }

  return theme('item_list', array('items' => $vars['breadcrumb'], 'attributes' => array('class' => array('breadcrumb'))));
}

/**
 * Generate an icon class from a path.
 */
function _stanley_icon_classes($path) {
  $classes = array();
  $args = explode('/', $path);
  if ($args[0] === 'admin' || (count($args) > 1 && $args[0] === 'node' && $args[1] === 'add')) {
    // Add a class specifically for the current path that allows non-cascading
    // style targeting.
    $classes[] = 'path-icon-'. str_replace('/', '-', implode('/', $args)) . '-active';
    while (count($args)) {
      $classes[] = 'path-icon-'. str_replace('/', '-', implode('/', $args));
      array_pop($args);
    }
    return $classes;
  }
  return array();
}
